/*
SDX: Documentary System in XML.
Copyright (C) 2000, 2001, 2002  Ministere de la culture et de la communication (France), AJLSM

Ministere de la culture et de la communication,
Mission de la recherche et de la technologie
3 rue de Valois, 75042 Paris Cedex 01 (France)
mrt@culture.fr, michel.bottin@culture.fr

AJLSM, 17, rue Vital Carles, 33000 Bordeaux (France)
sevigny@ajlsm.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
or connect to:
http://www.fsf.org/copyleft/gpl.html
*/
package fr.gouv.culture.sdx.utils.logging;

import org.apache.avalon.framework.logger.Logger;

import fr.gouv.culture.sdx.utils.Utilities;

public class LoggingUtils {

	/**Logs an information message
	 *
	 * @param logger    The super.getLog()
	 * @param s         The message
	 */
	public static void logInfo(Logger logger, String s) {
		if ( Utilities.checkString(s) && logger != null && logger.isInfoEnabled() )
			logger.info(s);
	}

	/**Logs a debug message
	 *
	 * @param logger    The super.getLog()
	 * @param s         The message (maybe null)
	 * @param e         The exception (maybe null)
	 */
	public static void logDebug(Logger logger, String s, Exception e) {
		if ( logger != null && logger.isDebugEnabled() ) {
			if (Utilities.checkString(s)) {
				if (e != null) {
					logger.debug(s, e);
				} else {
					logger.debug(s);
				}
			} else if (e != null && (e.getMessage() != null & e.fillInStackTrace() != null)) {
				logger.debug(e.getMessage(), e.fillInStackTrace());
			}
		}
	}
	/**
	 * 
	 * @see #logDebug(Logger, String, Exception)
	 */
	public static void logDebug(Logger logger, String s) {
		logDebug(logger, s, null);
	}

	/**Logs an error
	 *
	 * @param logger    The super.getLog()
	 * @param s         The message (maybe null)
	 * @param e         The exception (maybe null)
	 */
	public static void logError(Logger logger, String s, Throwable e) {
		if ( logger != null && logger.isErrorEnabled() ) {
			if (Utilities.checkString(s)) {
				if (e != null) {
					logger.error(s, e);
				} else
					logger.error(s);
			} else if (e != null && (e.getMessage() != null & e.fillInStackTrace() != null)) {
				logger.error(e.getMessage(), e.fillInStackTrace());
			}
		}
	}
	
	/**
	 * @see #logError(Logger, String, Throwable)
	 */
	public static void logError(Logger logger, String s) {
		logError(logger, s, null);
	}

	/**Logs a warning message
	 *
	 * @param logger    The super.getLog()
	 * @param s         The message (maybe null)
	 * @param e         The exception (maybe null)
	 */
	public static void logWarn(Logger logger, String s, Exception e) {
		if ( logger != null && logger.isWarnEnabled() ) {
			if (Utilities.checkString(s)) {
				if (e != null) {
					logger.warn(s, e);
				} else
					logger.warn(s);
			} else if (e != null)
				logger.warn(e.getMessage(), e);

		}
	}
	
	/**
	 * @see #logWarn(Logger, String, Exception)
	 */
	public static void logWarn(Logger logger, String s) {
		logWarn(logger, s, null);
	}

	/**Logs an exception
	 *
	 * @param logger    The super.getLog()
	 * @param e         The exception (maybe null)
	 */
	public static void logException(Logger logger, Exception e) {
		if ( logger != null && logger.isErrorEnabled() && e != null 
					&& ( e.getMessage() != null && e.fillInStackTrace() != null) ){ 
			logger.error(e.getMessage(), e.fillInStackTrace());
		}
	}
}
